# coding: utf-8

"""
    EmployeeEFCrud

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from EFCrud.models.employee import Employee

class TestEmployee(unittest.TestCase):
    """Employee unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Employee:
        """Test Employee
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Employee`
        """
        model = Employee()
        if include_optional:
            return Employee(
                employee_id = 56,
                name = '',
                age = 56,
                department = '',
                experience = 56,
                blood_group = '',
                father_name = '',
                is_deleted = True,
                is_active = True,
                date_of_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                date_of_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                roles = '',
                is_supervisor = True,
                is_manager = True
            )
        else:
            return Employee(
        )
        """

    def testEmployee(self):
        """Test Employee"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
